@@ -21,9 +21,11 @@ language_list=(
     '"Czech"      cs'
     '"Danish"     da'
     '"Dutch"      nl'
+    '"Finnish"    fi'
     '"French"     fr'
     '"German"     de'
     '"Hungarian"  hu'
+    '"Indonesian" id'
     '"Italian"    it'
     '"Macedonian" mk'
     '"Persian"    fa'
