@@ -1,6 +1,7 @@
 #!/bin/sh
 #
 # Copyright © 2010-2017 Dr. Tobias Quathamer <toddy@debian.org>
+#             2022 Dr. Helge Kreutzmann <debian@helgefjell.de>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,6 +19,9 @@
 translation="$1"
 addendum="$2"
 
+
+ismdoc=$(grep -l $translation ../mdoc.cache)
+
 # Use the header up until the first msgid
 # and remove the comment character
 translators=$(sed '/msgid/q;s/^#\s\+//' "$translation" |
@@ -36,11 +40,15 @@ number_translators=$(echo "$translators" | wc -l)
 # Output of common header
 echo "PO4A-HEADER:mode=after;position=^\.(TH|Dt);beginboundary=FakePo4aBoundary" > "$addendum"
 echo >> "$addendum"
-# Special case for manpages which use mdoc syntax (currently only tar.1)
-case $(basename "$translation") in
-	tar.1.po ) echo ".Sh TRADUCERE" >> "$addendum" ;;
-	* ) echo ".SH TRADUCERE" >> "$addendum" ;;
-esac
+
+# Special case for manpages which use mdoc syntax
+if [ $ismdoc ]; then
+    # MDOC File
+    echo ".Sh TRADUCERE" >> "$addendum"
+else
+    # Groff file
+    echo ".SH TRADUCERE" >> "$addendum"
+fi
 echo "Traducerea în limba română a acestui manual a fost creată de" >> "$addendum"
 
 # Warn if the translators string is empty
@@ -65,3 +73,12 @@ fi
 
 # Output of common ending
 echo "." >> "$addendum"
+
+# Special case for manpages which use mdoc syntax
+if [ $ismdoc ]; then
+    # MDOC File
+    cat license-mdoc.add >> "$addendum"
+else
+    # Groff file
+    cat license-groff.add >> "$addendum"
+fi
